@@ -44,12 +44,12 @@ class DataflowDeployer(BaseDeployer):
         self.success_message = f"[SUCCESS] Service deployed - it can be questioned via Pub/Sub at {self.service_id!r}."
 
         # Optional configuration file entries for Dataflow.
-        self.temporary_files_location = self._octue_configuration.get(
+        self.temporary_files_location = self._service.get(
             "temporary_files_location", DEFAULT_DATAFLOW_TEMPORARY_FILES_LOCATION
         )
-        self.setup_file_path = self._octue_configuration.get("setup_file_path", DEFAULT_SETUP_FILE_PATH)
-        self.service_account_email = self._octue_configuration.get("service_account_email")
-        self.worker_machine_type = self._octue_configuration.get("worker_machine_type")
+        self.setup_file_path = self._service.get("setup_file_path", DEFAULT_SETUP_FILE_PATH)
+        self.service_account_email = self._service.get("service_account_email")
+        self.worker_machine_type = self._service.get("machine_type")
 
     def deploy(self, no_cache=False, update=False):
         """Create a Google Cloud Build configuration from the `octue.yaml file, create a build trigger, run it, and
@@ -121,7 +121,7 @@ class DataflowDeployer(BaseDeployer):
 
             if self.provided_cloud_build_configuration_path:
                 progress_message.finish_message = (
-                    f"skipped - using {self._octue_configuration['cloud_build_configuration_path']!r} from repository."
+                    f"skipped - using {self.provided_cloud_build_configuration_path!r} from repository."
                 )
                 return
 
@@ -132,25 +132,37 @@ class DataflowDeployer(BaseDeployer):
             else:
                 cache_option = []
 
+            required_environment_variable_build_args = [
+                f"--build-arg={name}={value}" for name, value in self.required_environment_variables.items()
+            ]
+
+            available_secrets_option, build_secrets = self._create_build_secrets_sections()
+
             self.generated_cloud_build_configuration = {
                 "steps": [
                     *get_dockerfile_step,
                     {
                         "id": "Build image",
                         "name": "gcr.io/cloud-builders/docker",
+                        "entrypoint": "bash",
                         "args": [
-                            "build",
-                            *cache_option,
-                            *[
-                                f"--build-arg={name}={value}"
-                                for name, value in self.required_environment_variables.items()
-                            ],
-                            "-t",
-                            self.image_uri_template,
-                            ".",
-                            "-f",
-                            dockerfile_path,
+                            "-c",
+                            " ".join(
+                                [
+                                    "docker",
+                                    "build",
+                                    *cache_option,
+                                    "'-t'",
+                                    f"{self.image_uri_template!r}",
+                                    *build_secrets["build_args"],
+                                    *required_environment_variable_build_args,
+                                    ".",
+                                    "'-f'",
+                                    dockerfile_path,
+                                ]
+                            ),
                         ],
+                        **build_secrets["secret_env"],
                     },
                     {
                         "id": "Push image",
@@ -172,4 +184,5 @@ class DataflowDeployer(BaseDeployer):
                     },
                 ],
                 "images": [self.image_uri_template],
+                **available_secrets_option,
             }
