@@ -1,11 +1,11 @@
 import json
 import os
-import warnings
 
 import octue.migrations.manifest
 from octue.cloud import storage
 from octue.cloud.storage import GoogleCloudStorageClient
 from octue.exceptions import InvalidInputException
+from octue.migrations.cloud_storage import translate_bucket_name_and_path_in_bucket_to_cloud_path
 from octue.mixins import Hashable, Identifiable, Pathable, Serialisable
 from octue.resources.dataset import Dataset
 
@@ -40,33 +40,28 @@ class Manifest(Pathable, Serialisable, Identifiable, Hashable):
         vars(self).update(**kwargs)
 
     @classmethod
-    def from_cloud(cls, project_name=None, cloud_path=None, bucket_name=None, path_to_manifest_file=None):
-        """Instantiate a Manifest from Google Cloud storage. Either (`bucket_name` and `path_to_manifest_file`) or
-        `cloud_path` must be provided.
+    def from_cloud(
+        cls,
+        cloud_path=None,
+        bucket_name=None,
+        path_to_manifest_file=None,
+    ):
+        """Instantiate a Manifest from Google Cloud storage.
 
         :param str|None cloud_path: full path to manifest in cloud storage (e.g. `gs://bucket_name/path/to/manifest.json`)
-        :param str|None bucket_name: name of bucket manifest is stored in
-        :param str|None path_to_manifest_file: path to manifest in cloud storage e.g. `path/to/manifest.json`
         :return Dataset:
         """
-        if project_name:
-            warnings.warn(
-                message="The `project_name` parameter is no longer needed and will be removed soon.",
-                category=DeprecationWarning,
-            )
+        if not cloud_path:
+            cloud_path = translate_bucket_name_and_path_in_bucket_to_cloud_path(bucket_name, path_to_manifest_file)
 
-        if cloud_path:
-            bucket_name, path_to_manifest_file = storage.path.split_bucket_name_from_gs_path(cloud_path)
+        bucket_name, path_to_manifest_file = storage.path.split_bucket_name_from_gs_path(cloud_path)
 
-        serialised_manifest = json.loads(
-            GoogleCloudStorageClient().download_as_string(bucket_name=bucket_name, path_in_bucket=path_to_manifest_file)
-        )
+        serialised_manifest = json.loads(GoogleCloudStorageClient().download_as_string(cloud_path))
 
         datasets = {}
 
         for key, dataset in serialised_manifest["datasets"].items():
-            dataset_bucket_name, path = storage.path.split_bucket_name_from_gs_path(dataset)
-            datasets[key] = Dataset.from_cloud(bucket_name=dataset_bucket_name, path_to_dataset_directory=path)
+            datasets[key] = Dataset.from_cloud(dataset)
 
         return Manifest(
             id=serialised_manifest["id"],
@@ -74,33 +69,24 @@ class Manifest(Pathable, Serialisable, Identifiable, Hashable):
             datasets=datasets,
         )
 
-    def to_cloud(
-        self, project_name=None, cloud_path=None, bucket_name=None, path_to_manifest_file=None, store_datasets=False
-    ):
-        """Upload a manifest to a cloud location, optionally uploading its datasets into the same directory. Either
-        (`bucket_name` and `path_to_manifest_file`) or `cloud_path` must be provided.
+    def to_cloud(self, cloud_path=None, bucket_name=None, path_to_manifest_file=None, store_datasets=False):
+        """Upload a manifest to a cloud location, optionally uploading its datasets into the same directory.
 
         :param str|None cloud_path: full path to cloud storage location to store manifest at (e.g. `gs://bucket_name/path/to/manifest.json`)
-        :param str|None bucket_name: name of bucket to store manifest in
-        :param str|None path_to_manifest_file: cloud storage path to store manifest at e.g. `path/to/manifest.json`
         :param bool store_datasets: if True, upload datasets to same directory as manifest file
         :return str: gs:// path for manifest file
         """
-        if project_name:
-            warnings.warn(
-                message="The `project_name` parameter is no longer needed and will be removed soon.",
-                category=DeprecationWarning,
-            )
+        if not cloud_path:
+            cloud_path = translate_bucket_name_and_path_in_bucket_to_cloud_path(bucket_name, path_to_manifest_file)
 
-        if cloud_path:
-            bucket_name, path_to_manifest_file = storage.path.split_bucket_name_from_gs_path(cloud_path)
+        bucket_name, path_to_manifest_file = storage.path.split_bucket_name_from_gs_path(cloud_path)
 
         datasets = {}
         output_directory = storage.path.dirname(path_to_manifest_file)
 
         for key, dataset in self.datasets.items():
             if store_datasets:
-                dataset_path = dataset.to_cloud(bucket_name=bucket_name, output_directory=output_directory)
+                dataset_path = dataset.to_cloud(storage.path.generate_gs_path(bucket_name, output_directory))
                 datasets[key] = dataset_path
             else:
                 datasets[key] = dataset.cloud_path or dataset.absolute_path
@@ -109,13 +95,8 @@ class Manifest(Pathable, Serialisable, Identifiable, Hashable):
         serialised_manifest["datasets"] = datasets
         del serialised_manifest["path"]
 
-        GoogleCloudStorageClient().upload_from_string(
-            string=json.dumps(serialised_manifest),
-            bucket_name=bucket_name,
-            path_in_bucket=path_to_manifest_file,
-        )
-
-        return cloud_path or storage.path.generate_gs_path(bucket_name, path_to_manifest_file)
+        GoogleCloudStorageClient().upload_from_string(string=json.dumps(serialised_manifest), cloud_path=cloud_path)
+        return cloud_path
 
     @property
     def all_datasets_are_in_cloud(self):
